@@ -1,8 +1,8 @@
-#/usr/bin/python3
+# nextcloud_talk_extractor.py
 import argparse
-from read_data import read_nextcloud_data
-from nextcloud_requests import NextcloudRequests
-from permissions_map import permissions_map
+from .nextcloud_data import NextcloudData
+from .nextcloud_requests import NextcloudRequests
+from .permissions_map import permissions_map
 
 
 class NextcloudTalkExtractor:
@@ -106,7 +106,7 @@ class NextcloudTalkExtractor:
         }
         endpoint = f"/ocs/v2.php/apps/spreed/api/v1/chat/{room_id}"
         response = self.nextcloud_requests.send_request(endpoint, params=paramsMessages)
-        print(response)
+
         # Extract the participants IDs
         messages_list = []
         for message in response["ocs"]["data"]:
@@ -117,7 +117,7 @@ class NextcloudTalkExtractor:
 if __name__ == "__main__":
     parser = argparse.ArgumentParser(description=__doc__, formatter_class=argparse.RawDescriptionHelpFormatter)
     args = parser.parse_args()
-    data = read_nextcloud_data()
+    data = NextcloudData.read_nextcloud_data()
     for key, value in data.items():
         locals()[key] = value
     extractor = NextcloudTalkExtractor(NEXTCLOUD_URL, USERNAME, PASSWORD)
